
# <span class="fa fa-server"></span>&nbsp; Supporting Development

This page is dedicated to the various people, tools, technologies, and companies which support the development of PySceneDetect.  This page has been created to give credit to the things which allow PySceneDetect to exist, and is not meant to imply any kind of endorsement.


## <span class="fa fa-cogs"></span>&nbsp; Tools, Technologies, and Companies

The development of PySceneDetect is supported by the following tools, technologies, and companies:

 - [Github](https://github.com/) - Source code hosting, review, and linting
 - [Travis.CI](https://www.travis-ci.com/) - Linux builds and testing
 - [AppVeyor](https://www.appveyor.com/) - Windows builds and testing
 - [AdvancedInstaller](https://www.advancedinstaller.com/) - MSI installer
 - [SignPath](https://signpath.io/) - Code signing for Windows builds

Special thanks to these companies for their support.


## <span class="fa fa-users"></span>&nbsp; Community Contributions

PySceneDetect is an open source project which anyone can freely contribute to (see [this page for various ways you can contribute](contributing.md)).  You can view [the contribution graph on Github](https://github.com/Breakthrough/PySceneDetect/graphs/contributors) or [visit PySceneDetect at libraries.io](https://libraries.io/github/Breakthrough/PySceneDetect/contributors) or view the to see a list detailing the contributions people have made to the PySceneDetect project.

In addition to those who have made a direct contribution in the form of a pull request, a special thank you to *everyone* who has submitted an issue, bug report, feature request, and/or pull request (see the links above for complete lists), as well as for those who continue to help the ongoing development of PySceneDetect.

Your contributions continue to improve PySceneDetect, highlight the assets and talents of the FOSS community, and help to make the project's goal of being the most accurate scene detection program/library become a reality.  Lastly, thank you all for your help, support, feedback, and direction on the project.


## <span class="fa fa-money-check"></span>&nbsp; Donations

Monetary donations are not accepted for the project, but [there are ways you can contribute](contributing.md) to the project.  Furthermore, if you have resources, tools, or technologies which may benefit the development of PySceneDetect, please feel free to contact me via the issue tracker or [my website](http://bcastell.com/contact/).

Many thanks to everyone who continually supports the development of the project.
